@@ -13,8 +13,7 @@ def looper():
     file = Browse(
         root,
         type="dir",
-        title="Select Directory with User Planning",
-        initial=initial,
+        title="Select Directory Excel Files for Extraction",
     )
     OkButton(root, function=lambda: close(file_path=file, root=root))
     root.protocol("WM_DELETE_WINDOW", lambda: on_closing(parent=root))
